package com.ruoyi.frequency.workstep.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.frequency.workstep.entity.WorkStep;
import com.ruoyi.vo.UserVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 作品踩Mapper接口
 * 
 * @author liwenlong
 * @date 2023-10-12
 */
public interface WorkStepMapper  extends BaseMapper<WorkStep>
{
    /**
     * 查询作品踩
     * 
     * @param id 作品踩主键
     * @return 作品踩
     */
    public WorkStep selectWorkStepById(Long id);

    /**
     * 查询作品踩列表
     * 
     * @param workStep 作品踩
     * @return 作品踩集合
     */
    public List<WorkStep> selectWorkStepList(WorkStep workStep);

    /**
     * 新增作品踩
     * 
     * @param workStep 作品踩
     * @return 结果
     */
    public int insertWorkStep(WorkStep workStep);

    /**
     * 修改作品踩
     * 
     * @param workStep 作品踩
     * @return 结果
     */
    public int updateWorkStep(WorkStep workStep);

    /**
     * 删除作品踩
     * 
     * @param id 作品踩主键
     * @return 结果
     */
    public int deleteWorkStepById(Long id);

    /**
     * 批量删除作品踩
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWorkStepByIds(Long[] ids);

    void workStep(@Param("req")WorkStep workStep, @Param("userVo")UserVo userVo);
}
